@@ -18,7 +18,7 @@ File::ConfigDir - Get directories of configuration files
 
 =cut
 
-$VERSION   = '0.016';
+$VERSION   = '0.017';
 @ISA       = qw(Exporter);
 @EXPORT    = ();
 @EXPORT_OK = (
@@ -281,7 +281,12 @@ pkgsrc ;)
 =cut
 
 my $singleapp_cfg_dir = sub {
-    my @dirs = ( Cwd::abs_path( File::Spec->catdir( $FindBin::RealDir, "..", "etc" ) ) );
+    my @dirs = (
+        map
+        {
+            eval { Cwd::abs_path($_) } or File::Spec->canonpath($_)
+        } File::Spec->catdir( $FindBin::RealDir, "..", "etc" )
+    );
     @dirs;
 };
 
